============
Installation
============

At the command line::

    $ pip install orpheum

Or, if you have conda or [Anaconda](https://www.anaconda.com/products/individual) installed::

    $ conda create -n orpheum python=3.7
    $ pip install orpheum
